@@ -202,7 +202,7 @@ def get_background(zodia_level, earthshine_level, wavearr, spaxel_xsize, spaxel_
 
 
 
-class DetectorCountsRate(source.ModelCube):
+class SourceCountsRate(source.ModelCube):
 
     def __init__(self, config):
 
@@ -225,7 +225,7 @@ class DetectorCountsRate(source.ModelCube):
 
 
 
-class DetectorCounts(object):
+class NoiseCounts(object):
 
     def __init__(self, config, signal):
 
@@ -332,9 +332,9 @@ class calculation_snr(object):
 
     def __init__(self, config):
 
-        signal_rate = DetectorCountsRate(config)
+        signal_rate = SourceCountsRate(config)
 
-        counts = DetectorCounts(config, signal_rate)
+        counts = NoiseCounts(config, signal_rate)
 
         self.source = counts.nsource
         self.darknoise = np.sqrt(counts.ndark)
@@ -399,11 +399,12 @@ class calculation_snr(object):
         fig, axs = plt.subplots(figsize=(12, 9))
         fig.subplots_adjust(hspace=0.35, wspace=0.45,
                             left=0.05, right=0.97, top=0.95, bottom=0.05)
-        cm = plt.cm.get_cmap('jet_r')
+        cm = plt.cm.get_cmap('jet')
+        cm_r = plt.cm.get_cmap('jet_r')
 
         ax_recontructed_magmap = plt.subplot2grid((3, 4), (0, 0))
         im = ax_recontructed_magmap.imshow(self.img2d, origin='low', extent=(0, 30, 0, 30),
-                                           cmap=cm, picker=True)
+                                           cmap=cm_r, picker=True)
         ax_recontructed_magmap.set_xlabel('spaxel')
         ax_recontructed_magmap.set_ylabel('spaxel')
         ax_recontructed_magmap.set_title('reconstructed magmap')
@@ -412,17 +413,17 @@ class calculation_snr(object):
         cbar.set_label(r'mag/arcsec$^{2}$', labelpad=-1)
         cbar.ax.tick_params(labelsize=7)
 
-        ax_recontructed_snr = plt.subplot2grid((3, 4), (1, 0))
+        # ax_recontructed_snr = plt.subplot2grid((3, 4), (1, 0))
         ind = np.argmin(abs(self.mockwave - 5000))
-        im = ax_recontructed_snr.imshow(self.snr[ind, :, :], origin='low', extent=(0, 30, 0, 30),
-                                        cmap=cm, picker=True)
-        ax_recontructed_snr.set_xlabel('spaxel')
-        ax_recontructed_snr.set_ylabel('spaxel')
-        ax_recontructed_snr.set_title('reconstructed SNR@5000A')
-        cbar_ax = fig.add_axes([0.25, 0.41, 0.01, 0.2])
-        cbar = plt.colorbar(im, cax=cbar_ax, ticks=np.arange(0, 4, 1), orientation='vertical')
-        cbar.set_label('SNR', labelpad=-1)
-        cbar.ax.tick_params(labelsize=7)
+        # im = ax_recontructed_snr.imshow(self.snr[ind, :, :], origin='low', extent=(0, 30, 0, 30),
+        #                                 cmap=cm, picker=True)
+        # ax_recontructed_snr.set_xlabel('spaxel')
+        # ax_recontructed_snr.set_ylabel('spaxel')
+        # ax_recontructed_snr.set_title('reconstructed SNR@5000A')
+        # cbar_ax = fig.add_axes([0.25, 0.41, 0.01, 0.2])
+        # cbar = plt.colorbar(im, cax=cbar_ax, ticks=np.arange(0, 4, 1), orientation='vertical')
+        # cbar.set_label('SNR', labelpad=-1)
+        # cbar.ax.tick_params(labelsize=7)
 
         k = 0
         i = 15
@@ -445,7 +446,7 @@ class calculation_snr(object):
         ax_noises.plot(self.mockwave, self.darknoise[:, j, i], label='dark_noise')
         ax_noises.plot(self.mockwave, self.straynoise[:, j, i], label='stray_noise')
         ax_noises.legend(loc=1)
-        ax_noises.set_ylabel('noise counts (e-/s)')
+        ax_noises.set_ylabel('noise counts (e-)')
 
         ax_recontructed_spec = plt.subplot2grid((3, 3), (k + 2, 1), colspan=2)
         ax_recontructed_spec.plot(self.mockwave, self.mockflux[:, j, i], 'k-', label='mockflux')
@@ -488,7 +489,7 @@ class calculation_snr(object):
             ax_noises.plot(self.mockwave, self.darknoise[:, j, i], label='dark_noise')
             ax_noises.plot(self.mockwave, self.straynoise[:, j, i], label='stray_noise')
             ax_noises.legend(loc=1)
-            ax_noises.set_ylabel('noise counts (e-/s)')
+            ax_noises.set_ylabel('noise counts (e-)')
 
             ax_recontructed_spec = plt.subplot2grid((3, 3), (k + 2, 1), colspan=2)
             ax_recontructed_spec.plot(self.mockwave, self.mockflux[:, j, i], 'k-', label='mockflux')
