@@ -88,7 +88,7 @@ class read_template(object):
 
         # redshift correction
         template_wave = template_wave * (1 + template_redshift)
-        template_flux = template_flux / (1 + template_flux)
+        template_flux = template_flux / (1 + template_redshift)
 
         self.wave = template_wave
         self.flux = template_flux
